@@ -6,7 +6,7 @@ class Venue(models.Model):
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
 
-    def __init__(self):
+    """def __init__(self):
         self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
 
         if not os.path.exists(self.venue_root):
@@ -15,7 +15,7 @@ class Venue(models.Model):
             raise
         self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (self.venue_name))
         self.acts_dir = os.path.join(self.venue_root, 'acts')
-
+    """
 
     def get_settings(self):
         """ import the venue's settings.py"""
