@@ -30,9 +30,6 @@ TEMPLATE_DIRS.append('%s/instruments/local/templates/ads' % VENUE_ROOT)
 
 ROOT_URLCONF = '%s.urls' % (ACT_NAME)
 
-STATIC_ROOT = os.path.join(ACT_HOME, 'cstatic/')
-STATIC_URL = '/static/'
-
 for act in ACT_APPS:
     act in INSTALLED_APPS or INSTALLED_APPS.append(act)
 INSTALLED_APPS.insert(0, ACT_NAME)
